.. attention::

   CAMELS has grown! The Astrid suite  --containing 1,092 state-of-the-art hydrodynamic simulations run with the MP-Gadget code employing the same subgrid model as the Astrid simulation-- has been added to CAMELS. The N-body counterparts of these simulations are also available.

.. image:: Letters2.png
   :width:  800 px
   :height: 200 px
   :align: center

**CAMELS** stands for **C**\osmology and **A**\strophysics with **M**\achin\ **E** **L**\earning **S**\imulations, and is a suite 6,325 cosmological simulations: 3,049 N-body and 3,276 state-of-the-art (magneto-)hydrodynamic:

+--------------+--------------+---------------+-------------+
| Type         | Code         | Subgrid model | Simulations |
+==============+==============+===============+=============+
| Hydrodynamic | Arepo        |  IllustrisTNG |    1,092    |
+--------------+--------------+---------------+-------------+
| Hydrodynamic | Gizmo        |  SIMBA        |    1,092    |
+--------------+--------------+---------------+-------------+
| Hydrodynamic | MP-Gadget    |  Astrid       |    1,092    |
+--------------+--------------+---------------+-------------+
| N-body       | Gadget-III   |      ---      |    3,049    |
+--------------+--------------+---------------+-------------+

CAMELS is a massive dataset designed to build bridges between cosmology and astrophysics through machine learning. Containing almost half a petabyte of data, it is currently the largest set of cosmological hydrodynamic simulations ever run.

.. image:: CAMELS_diagram.png
   :alt: Cosmology, Astrophysics, Machine Learning, and Simulations

.. toctree::
   :maxdepth: 2
   :caption: Science

   goals
   publications

.. toctree::
   :maxdepth: 2
   :caption: Data accesss

   data_access

.. toctree::
   :maxdepth: 2
   :caption: Simulations

   description

.. toctree::
   :maxdepth: 2
   :caption: Data products

   organization
   snapshots
   subfind
   rockstar
   ahf
   caesar
   Pk
   Bk
   pdf
   VIDE
   Lya
   Xrays
   Profiles
   CMD
   SAM
   
.. toctree::
   :maxdepth: 2
   :caption: Post-processing
      
   images


.. toctree::
   :maxdepth: 2
   :caption: Libraries

   camels_library
   pylians3

.. toctree::
   :maxdepth: 2
   :caption: Other

   team
   contact
   citation
   logo
